#!/usr/local/bin/cl -f
#
#This macro uses IRAF to calculate
#the residual core flux using Halfa 
#Hbeta, MgTriplet, or CaTriplet.
#It NEEDS input.iraf file where it is stored
#the filename of the fits to be analysed
#and the radial velocity;
#It appends the output (residual core flux)
#in output_M01.iraf

noao
onedspec
images
imutil

{
string spectrum
string cont1
string cont2
string sre
string sing_p
string *input

real rvel
real vsuc
real crval
real cdelt
real crpix
real crstart
real npixel
real wshift
real minre
real min0
real medc1
real medc2
real rcf
real rcfmg1
real rcfmg2
real rcfmg3
real rcfhb
real rcfha
real rcfca1
real rcfca2
real rcfca3
real flux0
real crlast
real ha
real hb
real mg1
real mg2
real mg3
real ca1
real ca2
real ca3
real wlsh

int ha_w1
int ha_w2
int ha_c1
int ha_c2
int ha_c3
int ha_c4
int hb_w1
int hb_w2
int hb_c1
int hb_c2
int hb_c3
int hb_c4
int mg1_w1
int mg1_w2
int mg2_w1
int mg2_w2
int mg3_w1
int mg3_w2
int mg_c1
int mg_c2
int mg_c3
int mg_c4
int ca1_w1
int ca1_w2
int ca2_w1
int ca2_w2
int ca3_w1
int ca3_w2
int ca_c1
int ca_c2
int ca_c3
int ca_c4
int npixel1
int npixel2
int first0
int first1
int rcf_i
int esci

esci = 0
crval = INDEF
cdelt = INDEF
crpix = INDEF
npixel = INDEF
spectrum = INDEF
rvel = INDEF
input = "input.iraf"

while(fscan(input,spectrum,rvel) !=EOF) {
}
if (spectrum=="INDEF" || rvel==INDEF){
  print("IRAF: ...could not find all the needed information in input.iraf. Exiting.")
}
else {
  print("\nIRAF: using iraf script re.cl")
  print("IRAF: working on spectrum ",spectrum)
  printf("IRAF: radial velocity information is %6.1f km/s\n",rvel)
  print("IRAF: looking for keyword CRVAL1, CDELT1, CRPIX1, NAXIS1 ...")
  #Keyword MUST be read singularly otherwise bugs happen
  hselect(spectrum,"CRVAL1",yes) | scan(crval)
  hselect(spectrum,"CRPIX1",yes) | scan(crpix)
  hselect(spectrum,"NAXIS1",yes) | scan(npixel)
  hselect(spectrum,"CDELT1",yes) | scan(cdelt)
  if(crval==INDEF || crpix==INDEF || npixel==INDEF){
    print("IRAF: ...could not find all the needed information in the spectrum header. Exiting.")
  }
  else {
    print("IRAF: ... done!")
    crstart= crval-(crpix-1)*cdelt
    crlast = crval+(npixel*cdelt)
    crval  = crstart
    
    print("IRAF: CRVAL       ",crval)
    print("IRAF: CDELT       ",cdelt)
    print("IRAF: NPIXEL      ",npixel)
    print("IRAF: LAST PIXEL  ",crlast)
    
    vsuc= rvel/299792
    hb  = 4861.323*(1+vsuc)
    mg1 = 5167.321*(1+vsuc)
    mg2 = 5172.684*(1+vsuc)
    mg3 = 5183.604*(1+vsuc)
    ha  = 6562.797*(1+vsuc)
    ca1 = 8498.023*(1+vsuc)
    ca2 = 8542.091*(1+vsuc)
    ca3 = 8662.141*(1+vsuc)
    hb_c1 = 4842.0*(1+vsuc)
    hb_c4 = 4883.0*(1+vsuc)
    mg_c1 = 5150.3*(1+vsuc)
    mg_c4 = 5200.0*(1+vsuc) 
    ha_c1 = 6547.3*(1+vsuc)
    ha_c4 = 6585.8*(1+vsuc)
    ca_c1 = 8486.0*(1+vsuc)
    ca_c4 = 8690.0*(1+vsuc)    
    print("IRAF: now computing residual core flux ...")
    ####### RESIDUAL CORE FLUX
    minre=100
    rcfhb=100
    rcfmg1=100
    rcfmg2=100
    rcfmg3=100
    rcfha=100
    rcfca1=100
    rcfca2=100
    rcfca3=100
    ####### Computing rcf using H-beta
    if ( crstart<hb_c1 && crlast>hb_c4 ){
      #wshift = vsuc*4861.323
      #hb_w1 = (4859+wshift-crval)/cdelt
      #hb_w2 = (4862+wshift-crval)/cdelt
      hb_c1 = (4842*(1+vsuc)-crval)/cdelt
      hb_c2 = (4852*(1+vsuc)-crval)/cdelt
      hb_w1 = (4859*(1+vsuc)-crval)/cdelt
      hb_w2 = (4862*(1+vsuc)-crval)/cdelt
      hb_c3 = (4867*(1+vsuc)-crval)/cdelt
      hb_c4 = (4883*(1+vsuc)-crval)/cdelt
      s1 = spectrum//"["//hb_w1//":"//hb_w2//"]"
      cont1 = spectrum//"["//hb_c1//":"//hb_c2//"]"
      cont2 = spectrum//"["//hb_c3//":"//hb_c4//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      imstat(cont1,fields="midpt",format=no) | scan (medc1)
      imstat(cont2,fields="midpt",format=no) | scan (medc2)
      rcfhb = min0/((medc1+medc2)/2)
      if (rcfhb<minre) { 
        minre=rcfhb
        sre = "IRAF: ...using H-beta line 4861.323 shifted at "
        wlsh = hb
        wshift = vsuc*4861.323
      }
      ;
      esci=esci+1
    }
    ;
    ####### Computing rcf using MgTriplet
    if ( crstart<mg_c1 && crlast>mg_c4 ){
      #wshift = vsuc*5167.321
      #mg1_w1 = (5166.5+wshift-crval)/cdelt
      #mg1_w2 = (5168.1+wshift-crval)/cdelt
      mg_c1 = (5150.3*(1+vsuc)-crval)/cdelt
      mg_c2 = (5160.3*(1+vsuc)-crval)/cdelt
      mg1_w1 = (5166.5*(1+vsuc)-crval)/cdelt
      mg1_w2 = (5168.1*(1+vsuc)-crval)/cdelt
      mg2_w1 = (5171.8*(1+vsuc)-crval)/cdelt
      mg2_w2 = (5173.5*(1+vsuc)-crval)/cdelt
      mg3_w1 = (5182.8*(1+vsuc)-crval)/cdelt
      mg3_w2 = (5184.4*(1+vsuc)-crval)/cdelt
      mg_c3 = (5190.0*(1+vsuc)-crval)/cdelt
      mg_c4 = (5200.0*(1+vsuc)-crval)/cdelt
      s1 = spectrum//"["//mg1_w1//":"//mg1_w2//"]"
      cont1 = spectrum//"["//mg_c1//":"//mg_c2//"]"
      cont2 = spectrum//"["//mg_c3//":"//mg_c4//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      imstat(cont1,fields="midpt",format=no) | scan (medc1)
      imstat(cont2,fields="midpt",format=no) | scan (medc2)
      rcfmg1 = min0/((medc1+medc2)/2)
      s1 = spectrum//"["//mg2_w1//":"//mg2_w2//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      rcfmg2 = min0/((medc1+medc2)/2)
      s1 = spectrum//"["//mg3_w1//":"//mg3_w2//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      rcfmg3 = min0/((medc1+medc2)/2)
      if ( rcfmg1 < minre) {
  	minre = rcfmg1
  	sre = "IRAF: ...using Mg-triplet line 5167.321 shifted at "
  	wlsh = mg1
  	wshift = vsuc*5167.321
      }
      ;
      if ( rcfmg2 < minre ) {
  	minre = rcfmg2
  	sre = "IRAF: ...using Mg-triplet line 5172.684 shifted at "
  	wlsh = mg2
  	wshift = vsuc*5172.684
      }
      ;
      if ( rcfmg3 < minre ) {
  	minre = rcfmg3
  	sre = "IRAF: ...using Mg-triplet line 5183.604 shifted at "
  	wlsh = mg3
        wshift = vsuc*5183.604
      }
      ;
      esci=esci+1
    }
    ;
    ####### Computing rcf using H-alpha
    if ( crstart<ha_c1 && crlast>ha_c4 ) {							     
      #wshift = vsuc*6562.797	     
      #ha_w1 = (6562.2+wshift-crval)/cdelt
      #ha_w2 = (6563.8+wshift-crval)/cdelt
      #ha = 6562.797+wshift	 
      ha_c1 = (6547.3*(1+vsuc)-crval)/cdelt
      ha_c2 = (6554.0*(1+vsuc)-crval)/cdelt
      ha_w1 = (6562.2*(1+vsuc)-crval)/cdelt
      ha_w2 = (6563.8*(1+vsuc)-crval)/cdelt
      ha_c3 = (6568.3*(1+vsuc)-crval)/cdelt
      ha_c4 = (6585.8*(1+vsuc)-crval)/cdelt
      s1 = spectrum//"["//ha_w1//":"//ha_w2//"]"
      cont1 = spectrum//"["//ha_c1//":"//ha_c2//"]"
      cont2 = spectrum//"["//ha_c3//":"//ha_c4//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      imstat(cont1,fields="midpt",format=no) | scan (medc1)
      imstat(cont2,fields="midpt",format=no) | scan (medc2)
      rcfha = min0/((medc1+medc2)/2)
      if ( rcfha < minre ) {
  	minre = rcfha
  	sre = "IRAF: ...using H-alfa 6562.797 shifted at "
  	wlsh = ha
  	wshift = vsuc*6562.797
      }
      ; 
      esci=esci+1 
    }
    ;
    ####### Computing rcf using CaTriplet
    if ( crstart<ca_c1 && crlast>ca_c4 ){
      ca_c1 = (8486.0*(1+vsuc)-crval)/cdelt
      ca_c2 = (8492.0*(1+vsuc)-crval)/cdelt
      ca1_w1 = (8497.3*(1+vsuc)-crval)/cdelt
      ca1_w2 = (8498.7*(1+vsuc)-crval)/cdelt
      ca2_w1 = (8541.3*(1+vsuc)-crval)/cdelt
      ca2_w2 = (8542.7*(1+vsuc)-crval)/cdelt
      ca3_w1 = (8661.3*(1+vsuc)-crval)/cdelt
      ca3_w2 = (8662.8*(1+vsuc)-crval)/cdelt
      ca_c3 = (8670.0*(1+vsuc)-crval)/cdelt
      ca_c4 = (8690.0*(1+vsuc)-crval)/cdelt
      s1 = spectrum//"["//ca1_w1//":"//ca1_w2//"]"
      cont1 = spectrum//"["//ca_c1//":"//ca_c2//"]"
      cont2 = spectrum//"["//ca_c3//":"//ca_c4//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      imstat(cont1,fields="midpt",format=no) | scan (medc1)
      imstat(cont2,fields="midpt",format=no) | scan (medc2)
      rcfca1 = min0/((medc1+medc2)/2)
      s1 = spectrum//"["//ca2_w1//":"//ca2_w2//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      rcfca2 = min0/((medc1+medc2)/2)
      s1 = spectrum//"["//ca3_w1//":"//ca3_w2//"]"
      imstat(s1,fields="min",format=no) | scan (min0)
      rcfca3 = min0/((medc1+medc2)/2)
      if ( rcfca1 < minre ) {
  	minre = rcfca1
  	sre = "IRAF: ...using Ca-Triplet 8498.023 shifted at "
  	wlsh = ca1
  	wshift = vsuc*8498.023
      }
      ;
      if ( rcfca2 < minre ) {
  	minre = rcfca2
  	sre = "IRAF: ...using Ca-Triplet 8542.091 shifted at "
  	wlsh = ca2
  	wshift = vsuc*8542.091
      }
      ;
      if ( rcfca3 < minre ) {
  	minre = rcfca3
  	sre = "IRAF: ...using Ca-Triplet 8662.141 shifted at "
  	wlsh = ca3
  	wshift = vsuc*8662.141
      }
      ;
      esci=esci+1
    }
    ; 
    if ( esci == 0 ){
      print("\nIRAF: wavelength range out of bound. Residual core flux set to 0.18.")
      rcf=0.18
    }
    else {
      rcf = minre 
      printf("%s %8.3f ...\n",sre,wlsh)
      printf("IRAF: radial velocity shift in Angstrom -> %8.3f\n",wshift)   
      printf("IRAF: RESIDUAL CORE FLUX   %8.3f\n",rcf)
      if ( rcf<0 ){
  	print("IRAF: residual core flux is negative. Setting it to 0.05.")
  	rcf=0.05
      }
      ;  
      if ( rcf>0.3 ){
  	print("IRAF: residual core flux is greater than 0.3. Setting it to 0.18.")
  	rcf=0.18
      }
      ;
    }
    rcf = rcf*100
    printf("re=%d\n",rcf, >> "output_M01.iraf")
  }
}
logout
}
