#!/bin/bash
#
#This module removes all the files created by the pipeline therefore:
#	main output files defined in pipe.opt
#	log files created by modules to track down DAOSPEC runs
#	fits files created by DAOSPEC (continuum and residuals fits)
#	output DAOSPEC files (*daospec)
#	fits files created by module5 (normalized and fit fits)
#	daospec files created by module5 (*M04.daospec)
#
#To avoid the removal of some files just comment lines starting
#with rm command
#
echo CLEAR: ----------   CLEAR module is now running...   ----------
if [ ! -f pipe.opt ]; then echo CLEAR: opt file pipe.opt does not exist.; exit 1; fi

infile=`grep -w inputf01 pipe.opt | cut -d= -f2`
out1=`grep -w output01 pipe.opt | cut -d= -f2`
out2=`grep -w output02 pipe.opt | cut -d= -f2`
out3=`grep -w output03 pipe.opt | cut -d= -f2`
out4=`grep -w output04 pipe.opt | cut -d= -f2`
outrev=`grep MAJfile.*= pipe.opt | cut -d= -f2`

for i in $infile $out1 $out2 $out3 $out4; do
  if [ -z $i ]; then
    echo CLEAR: files not defined in pipe.opt
    exit 1
  fi
done

#REMOVING MAIN OUTPUT FILES
for i in $out1 $out2 $out3 $out4 $outrev; do rm -fv $i; done

list=(`grep -v \# $infile | awk '{print $1}'`)
for fits in ${list[@]}; do
  path=`echo $fits | sed -e "s/\/[^\/]*$//"`
  file=`echo $fits | sed -e "s/.*\///"`
  rootname=`echo $file | cut -d. -f1`
  
#REMOVING DAOSPEC LOG FILES
  rm -fv ${path}/${rootname}_M01.log
  rm -fv ${path}/${rootname}_M02.log
  rm -fv ${path}/${rootname}_M03.log
  rm -fv ${path}/${rootname}_M04.log
#REMOVING DAOSPEC FITS FILES
  rm -fv ${path}/${rootname}*{C.fits,R.fits}	#Continuum and Residuals fits
#REMOVING module5 FITS FILES
  rm -fv ${path}/${rootname}*{N.fits,F.fits}	#Normalized and Fits fits
  rm -fv ${path}/${rootname}*{NU.fits,NL.fits}
#REMOVING *.daospec FILES
  rm -fv ${path}/${rootname}.daospec
  rm -fv ${path}/${rootname}M03.daospec
  rm -fv ${path}/${rootname}M04.daospec
#REMOVING moog and gala files
  rm -fv ${path}/${rootname}.in
  rm -fv ${path}/${rootname}.moog
  rm -fv ${path}/${rootname}.iron
  rm -fv ${path}/${rootname}.ges
  
done
echo CLEAR: ...OK
