#!/bin/bash
#It saves the following information for each spectrum in the inputlist:
# - file name
# - order of continuum used
# - at which module there was a DAOSPEC crash (if any)
# - the input FI parameter
# - the final FI parameter
# - if converged during module 2 (1, if not: 0)
# - input FW
# - output FW
# - final RE
# - input RV
# - output RV
# - RV dispersion
# - rms of the fit (average of the residuals provided by DAOSPEC
#
echo WSTAT: Now condensing some information
infile=`grep -w inputf01 pipe.opt | cut -d= -f2`
outf1=`grep -w output01 pipe.opt | cut -d= -f2`	
outf2=`grep -w output02 pipe.opt | cut -d= -f2`
outf3=`grep -w output03 pipe.opt | cut -d= -f2`

fwstat=fwstat.dat
wstathead="# fname OR crash iFI oFI conv iFW oFW RE iRV oRV sRV fitrms"
rm -f $fwstat

if [ ! -s $infile -o ! -s $outf1 -o ! -s $outf2 -o ! -s $outf3 ]; then
   echo WSTAT: I cannot find the needed files or are empty. Exiting ...
   exit 1
fi

list=(`grep -v \# $infile | awk '{print $1}'`)
ord=(`grep -v \# $infile | awk '{print $2}'`)
fwi=(`grep -v \# $infile | awk '{print $3}'`)
fxi=(`grep -v \# $infile | awk '{print $4}'`)
rvi=(`grep -v \# $infile | awk '{print $5}'`)
#rcf=(`grep -v \# $infile | awk '{print $6}'`)
#stype=(`grep -v \# $infile | awk '{print $7}'`)

echo $wstathead > $fwstat
index=0  
for fits in ${list[@]}; do
  rootname=`echo $fits | sed 's/.fits//g'`
  dfile=${rootname}.daospec
  cv3[$index]=-1     #tracks if converged in module 2
  dc[$index]=-1      #tracks daospec crash
  fixf[$index]=-1    #tracks if fixed fwhm at the end
  fwf[$index]=-1     #tracks final fwhm
  ref[$index]=-1     #tracks final re
  rvf[$index]=-1     #tracks final rv
  rvd[$index]=-1     #tracks rv dispersion
  res[$index]=-1     #tracks average residual of the fits
  grep -v \# $outf1 | grep -q $fits
  if [ $? != 0 ]; then
    dc[$index]=1
  else
    temp=`grep $fits $outf2 | awk '{print $20}'`	#get info on flag3 (2 for DC)
    if [ $temp -eq 2 ]; then
      dc[$index]=2
    elif [ $temp -eq 1 ]; then
      cv3[$index]=1
    elif [ $temp -eq 0 ]; then
      cv3[$index]=0
    fi
    if [ $temp -lt 2 ]; then
      temp2=`grep $fits $outf3 | awk '{print $20}'`	#get info on flag3 (2 for DC)
      if [ $temp2 -eq 2 ]; then
        dc[$index]=3
      elif [ $temp2 -lt 2 ]; then
        dc[$index]=0
      fi
    fi
    if [ $temp -lt 2 -a $temp2 -lt 2 ]; then
      #get info on fi parameter (1 if fixed)
      fixf[$index]=`grep $fits $outf3 | awk '{split($11,a,"=");print a[2]}'`	
      #get info on measured rv
      rvf[$index]=`grep $fits $outf3 | awk '{split($8,mi,"=");split($9,ma,"=");rv=(ma[2]+mi[2])/2;print rv }'`	
      #get info on final fwhm used
      fwf[$index]=`grep $fits $outf3 | awk '{split($17,fw,"=");print fw[2]}'`	
      #get info on the residual core flux (re) parameter used
      ref[$index]=`grep $fits $outf3 | awk '{split($7,re,"=");print re[2]}'`
      if [ -f $dfile ]; then 
        #get info on rv dispersion
        rvd[$index]=`awk 'NR==1{printf "%8.3f",$7}' $dfile`
        #get info on average fit residuals
        res[$index]=`awk 'NR==2{printf "%8.3f",$8}' $dfile`
      fi
    fi
  fi
  printf "%s %3d %2d %2d %2d %2d %7.3f %7.3f %2d %8.3f %8.3f %8.3f %8.3f\n" "$fits" "${ord[$index]}" "${dc[$index]}" "${fxi[$index]}" "${fxf[$index]}" "${cv3[$index]}" "${fwi[$index]}" "${fwf[$index]}" "${ref[$index]}" "${rvi[$index]}" "${rvf[$index]}" "${rvd[$index]}" "${res[$index]}" >> $fwstat
  ((index++))
done
echo WSTAT: Info saved in $fwstat.
